@@ -319,8 +319,9 @@ class Reader(ReaderWriterBase):
 
         if type is not None:
             valid = isinstance(value, type)
-            if type is int:  # bool is a subclass of int
-                valid = valid and not isinstance(value, bool)
+            if type is int and isinstance(value, bool):
+                # isinstance() is not sufficient, since bool is an int subclass
+                valid = False
             if not valid:
                 raise InvalidLineError(
                     "line does not match requested type", line, lineno
@@ -506,11 +507,12 @@ class Writer(ReaderWriterBase):
         elif isinstance(sample_dumps_result, bytes) and not self._fp_is_binary:
             self._dumps_result_conversion = DumpsResultConversion.DecodeToString
 
-    def write(self, obj: Any) -> None:
+    def write(self, obj: Any) -> int:
         """
         Encode and write a single object.
 
         :param obj: the object to encode and write
+        :return: number of characters or bytes written
         """
         if self._closed:
             raise RuntimeError("writer is closed")
@@ -531,14 +533,16 @@ class Writer(ReaderWriterBase):
         if self._flush:
             fp.flush()
 
-    def write_all(self, iterable: Iterable[Any]) -> None:
+        return len(line) + 1  # including newline
+
+    def write_all(self, iterable: Iterable[Any]) -> int:
         """
         Encode and write multiple objects.
 
         :param iterable: an iterable of objects
+        :return: number of characters or bytes written
         """
-        for obj in iterable:
-            self.write(obj)
+        return sum(self.write(obj) for obj in iterable)
 
     def _repr_for_wrapped(self) -> str:
         return repr_for_fp(self._fp)
@@ -557,7 +561,7 @@ def open(
 @overload
 def open(
     file: Openable,
-    mode: Literal["w", "a"],
+    mode: Literal["w", "a", "x"],
     *,
     dumps: Optional[DumpsCallable] = ...,
     compact: Optional[bool] = ...,
@@ -615,8 +619,8 @@ def open(
     :param mode: whether to open the file for reading (``r``),
         writing (``w``) or appending (``a``).
     """
-    if mode not in {"r", "w", "a"}:
-        raise ValueError("'mode' must be either 'r', 'w', or 'a'")
+    if mode not in {"r", "w", "a", "x"}:
+        raise ValueError("'mode' must be either 'r', 'w', 'a', or 'x'")
 
     cls = Reader if mode == "r" else Writer
     encoding = "utf-8-sig" if mode == "r" else "utf-8"
